@@ -3,7 +3,6 @@ import logging
 from django.conf import settings as django_settings
 from django.contrib.auth import authenticate, get_user_model, login, logout
 from django.http import Http404, HttpResponseRedirect
-from django.urls import reverse
 from django.views.generic import TemplateView
 from django.views.generic.base import RedirectView
 
@@ -14,6 +13,7 @@ from .forms import (
 )
 from .helpers import create_magiclink, get_or_create_user
 from .models import MagicLink
+from .utils import get_url_path
 
 User = get_user_model()
 log = logging.getLogger(__name__)
@@ -25,6 +25,7 @@ class Login(TemplateView):
     def get(self, request, *args, **kwargs):
         context = self.get_context_data(**kwargs)
         context['login_form'] = LoginForm(request.POST)
+        context['require_signup'] = settings.REQUIRE_SIGNUP
         return self.render_to_response(context)
 
     def post(self, request, *args, **kwargs):
@@ -44,10 +45,11 @@ class Login(TemplateView):
         magic_link = create_magiclink(email, request, redirect_url=next_url)
         magic_link.send(request)
 
-        sent_url = reverse('magiclink:login_sent')
-        if settings.LOGIN_SENT_REDIRECT:
-            sent_url = settings.LOGIN_SENT_REDIRECT
-        return HttpResponseRedirect(sent_url)
+        sent_url = get_url_path(settings.LOGIN_SENT_REDIRECT)
+        response = HttpResponseRedirect(sent_url)
+        if settings.REQUIRE_BROWSER:
+            response.cookies['magiclink'] = magic_link.cookie_value
+        return response
 
 
 class LoginSent(TemplateView):
@@ -69,7 +71,6 @@ class LoginVerify(RedirectView):
         login(request, user)
 
         magic_link = MagicLink.objects.get(token=token)
-
         return HttpResponseRedirect(magic_link.redirect_url)
 
 
@@ -114,18 +115,25 @@ class Signup(TemplateView):
             first_name=first_name,
             last_name=last_name
         )
-        next_url = request.GET.get('next', settings.SIGNUP_REDIRECT)
+        next_url = request.GET.get('next', settings.SIGNUP_LOGIN_REDIRECT)
         magic_link = create_magiclink(email, request, redirect_url=next_url)
         magic_link.send(request)
 
-        sent_url = reverse('magiclink:login_sent')
-        if settings.LOGIN_SENT_REDIRECT:
-            sent_url = settings.LOGIN_SENT_REDIRECT
-        return HttpResponseRedirect(sent_url)
+        sent_url = get_url_path(settings.LOGIN_SENT_REDIRECT)
+        response = HttpResponseRedirect(sent_url)
+        if settings.REQUIRE_BROWSER:
+            response.cookies['magiclink'] = magic_link.cookie_value
+        return response
 
 
 class Logout(RedirectView):
 
     def get(self, request, *args, **kwargs):
         logout(self.request)
-        return HttpResponseRedirect(django_settings.LOGOUT_REDIRECT_URL)
+
+        next_page = request.GET.get('next')
+        if next_page:
+            return HttpResponseRedirect(next_page)
+
+        redirect_url = get_url_path(django_settings.LOGOUT_REDIRECT_URL)
+        return HttpResponseRedirect(redirect_url)
